@@ -13,7 +13,7 @@ __all__ = [
 
 def fallback_to_default(name, field):
     def getter(self):
-        return getattr(self, to_attribute(name)) or getattr(
+        return getattr(self, to_attribute(name), None) or getattr(
             self, to_attribute(name, field.languages[0])
         )
 
@@ -22,18 +22,14 @@ def fallback_to_default(name, field):
 
 def fallback_to_any(name, field):
     def getter(self):
-        current = getattr(self, to_attribute(name))
-
-        return current or next(
-            filter(
-                None,
-                (
-                    getattr(self, to_attribute(name, language))
-                    for language in field.languages
-                ),
-            ),
-            "",
-        )
+        current = getattr(self, to_attribute(name), None)
+        if current:
+            return current
+        for language in field.languages:
+            value = getattr(self, to_attribute(name, language))
+            if value:
+                return value
+        return ""
 
     return getter
 
